contentPadding property
Padding applied around the content widget of every panel.
Defaults to EdgeInsets.fromLTRB(16, 0, 16, 14).
Implementation
final EdgeInsetsGeometry contentPadding;
Padding applied around the content widget of every panel.
Defaults to EdgeInsets.fromLTRB(16, 0, 16, 14).
final EdgeInsetsGeometry contentPadding;