backgroundColor property

Color? backgroundColor
final

Background fill color. When null, a deterministic color is derived from name (or a neutral grey is used when both are absent).

Implementation

final Color? backgroundColor;