imageUrl property
Optional network image URL. When provided, the image is loaded from the network; if it fails to load, initials (or the person icon) are shown.
Implementation
final String? imageUrl;
Optional network image URL. When provided, the image is loaded from the network; if it fails to load, initials (or the person icon) are shown.
final String? imageUrl;