activeColor property
Color used for the active item icon and label. Defaults to the theme's primary color.
Implementation
final Color? activeColor;
Color used for the active item icon and label. Defaults to the theme's primary color.
final Color? activeColor;