AuiBottomSheet class

AuiBottomSheet — a static helper class for displaying modal bottom sheets with consistent styling across the AuraUI library.

All configuration is done through AuiBottomSheet.show.

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

show<T>({required BuildContext context, required WidgetBuilder builder, String? title, bool showDragHandle = true, bool isDismissible = true, bool enableDrag = true, Color? backgroundColor, double borderRadius = 20.0, double maxHeightFactor = 0.9, EdgeInsetsGeometry padding = const EdgeInsets.fromLTRB(16, 0, 16, 16)}) → Future<T?>
Displays a customizable modal bottom sheet.