activeColor property
The color used for the checkbox background when it is checked or indeterminate.
Falls back to ColorScheme.primary when null.
Implementation
final Color? activeColor;
The color used for the checkbox background when it is checked or indeterminate.
Falls back to ColorScheme.primary when null.
final Color? activeColor;