disabled property
Whether the checkbox (and its label) ignores all user input.
When true the checkbox is rendered with a grey fill to indicate the
disabled state. Defaults to false.
Implementation
final bool disabled;
Whether the checkbox (and its label) ignores all user input.
When true the checkbox is rendered with a grey fill to indicate the
disabled state. Defaults to false.
final bool disabled;