labelPosition property
Where the label is rendered relative to the checkbox.
Defaults to CheckboxLabelPosition.right.
Implementation
final CheckboxLabelPosition labelPosition;
Where the label is rendered relative to the checkbox.
Defaults to CheckboxLabelPosition.right.
final CheckboxLabelPosition labelPosition;