onChanged property

ValueChanged<bool?>? onChanged
final

Called when the user taps the checkbox or its label.

Receives the new value. When tristate is true the cycle is false → true → null → false …; when false the cycle is false → true → false ….

Pass null (or set disabled to true) to prevent interaction.

Implementation

final ValueChanged<bool?>? onChanged;