color property
Base / accent colour used to derive background, border, and text colours.
Defaults to ColorScheme.primary of the ambient Theme.
Implementation
final Color? color;
Base / accent colour used to derive background, border, and text colours.
Defaults to ColorScheme.primary of the ambient Theme.
final Color? color;