label property

String? label
final

Optional label text.

  • On a linear bar the label is shown right-aligned below the bar.
  • On a circular indicator the label is shown centred inside the ring.

Implementation

final String? label;