AuiRadioOption<T> class

A single option in AuiRadioGroup.

Constructors

AuiRadioOption({required T value, required String label, String? subtitle, bool disabled = false})
Creates an AuiRadioOption with the given value and label.
const

Properties

disabled bool
Whether this option is non-interactive.
final
hashCode int
The hash code for this object.
no setterinherited
label String
The primary label displayed next to the radio button.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
subtitle String?
An optional secondary description displayed below label.
final
value → T
The value represented by this option.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited