AuiStep class

A single step in AuiStepper.

Constructors

AuiStep({required String title, String? subtitle, AuiStepState state = AuiStepState.pending})
Creates an AuiStep with a required title, optional subtitle, and an optional state (defaults to AuiStepState.pending).
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
state → AuiStepState
The current state of this step.
final
subtitle → String?
An optional secondary label shown below title.
final
title → String
The primary label shown beneath / beside the step indicator.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited