onChanged property
Called when the user taps the switch. Pass null to disable tap handling
(prefer using disabled instead so opacity is also applied).
Implementation
final ValueChanged<bool>? onChanged;
Called when the user taps the switch. Pass null to disable tap handling
(prefer using disabled instead so opacity is also applied).
final ValueChanged<bool>? onChanged;