activeColor property
Color used for the active tab indicator and active label. Falls back to ColorScheme.primary when not provided.
Implementation
final Color? activeColor;
Color used for the active tab indicator and active label. Falls back to ColorScheme.primary when not provided.
final Color? activeColor;