error property
When non-null, renders the string as an error message below the field and highlights borders in the error color.
Implementation
final String? error;
When non-null, renders the string as an error message below the field and highlights borders in the error color.
final String? error;