maxLength property
When set, displays a character counter below the field in the form
"<current> / <maxLength>".
Implementation
final int? maxLength;
When set, displays a character counter below the field in the form
"<current> / <maxLength>".
final int? maxLength;