padding property
Inner padding around the message text inside the tooltip bubble.
Defaults to EdgeInsets.symmetric(horizontal: 10, vertical: 6).
Implementation
final EdgeInsetsGeometry padding;
Inner padding around the message text inside the tooltip bubble.
Defaults to EdgeInsets.symmetric(horizontal: 10, vertical: 6).
final EdgeInsetsGeometry padding;