waitDuration property
How long the pointer must hover before the tooltip is shown.
Defaults to Duration(milliseconds: 500).
Implementation
final Duration waitDuration;
How long the pointer must hover before the tooltip is shown.
Defaults to Duration(milliseconds: 500).
final Duration waitDuration;