BadgePosition enum
The corner position where the badge is anchored on its child widget.
Values
- topRight → const BadgePosition
-
Top-right corner of the child.
- topLeft → const BadgePosition
-
Top-left corner of the child.
- bottomRight → const BadgePosition
-
Bottom-right corner of the child.
- bottomLeft → const BadgePosition
-
Bottom-left corner of the child.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
BadgePosition> - A constant List of the values in this enum, in order of their declaration.