Sparkle class

Constructors

Sparkle({required String id, required double x, required double y, required Color color, required double delay, required double scale, required double lifespan})

Properties

color → Color
final
delay → double
final
hashCode → int
The hash code for this object.
no setterinherited
id → String
final
lifespan ↔ double
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double
final
x → double
final
y → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited