TabIndicatorStyle enum

Controls the visual style used to indicate the active tab.

Inheritance
Available extensions

Values

underline → const TabIndicatorStyle

A 2 px line drawn at the bottom of the active tab.

pill → const TabIndicatorStyle

A filled pill (rounded rectangle) behind the active tab label.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<TabIndicatorStyle>
A constant List of the values in this enum, in order of their declaration.