TooltipPosition enum
The preferred position for an AuiTooltip relative to its child.
Note: Flutter's built-in Tooltip widget only supports above/below placement. TooltipPosition.left falls back to TooltipPosition.top and TooltipPosition.right falls back to TooltipPosition.bottom.
Values
- top → const TooltipPosition
-
Display the tooltip above the child.
- bottom → const TooltipPosition
-
Display the tooltip below the child.
- left → const TooltipPosition
-
Display the tooltip to the left of the child. Falls back to top placement because Flutter's Tooltip does not support horizontal-only positioning natively.
- right → const TooltipPosition
-
Display the tooltip to the right of the child. Falls back to bottom placement because Flutter's Tooltip does not support horizontal-only positioning natively.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
TooltipPosition> - A constant List of the values in this enum, in order of their declaration.