AuiAccordion class
A vertically stacked list of collapsible panels.
Each panel is described by an AuiAccordionItem. By default only one
panel can be open at a time (allowMultiple: false). Set
allowMultiple: true to allow several panels to be open simultaneously.
Example — basic single-open accordion:
AuiAccordion(
items: [
AuiAccordionItem(title: 'Section 1', child: Text('Content')),
AuiAccordionItem(title: 'Section 2', child: Text('More content')),
],
)
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatefulWidget
- AuiAccordion
Constructors
-
AuiAccordion({Key? key, required List<
AuiAccordionItem> items, bool allowMultiple = false, Color? dividerColor, Color? activeHeaderColor, EdgeInsetsGeometry headerPadding = const EdgeInsets.symmetric(horizontal: 16, vertical: 14), EdgeInsetsGeometry contentPadding = const EdgeInsets.fromLTRB(16, 0, 16, 14)}) -
Creates an AuiAccordion.
const
Properties
- activeHeaderColor → Color?
-
Background color applied to the header row when the panel is expanded.
final
- allowMultiple → bool
-
When
false(the default) tapping a header closes the previously open panel before opening the new one. Whentrueany number of panels may be open simultaneously.final - contentPadding → EdgeInsetsGeometry
-
Padding applied around the content widget of every panel.
final
- dividerColor → Color?
-
Color of the dividers between panels.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headerPadding → EdgeInsetsGeometry
-
Padding applied to every panel header row.
final
-
items
→ List<
AuiAccordionItem> -
The list of panels to display.
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → State< AuiAccordion> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited