onDelete property
When non-null, an × icon button is shown on the trailing edge and this callback is invoked when the user taps it.
Implementation
final VoidCallback? onDelete;
When non-null, an × icon button is shown on the trailing edge and this callback is invoked when the user taps it.
final VoidCallback? onDelete;