suffixIcon property
Optional icon shown at the trailing edge of the field.
When obscureText is true this icon is replaced by a visibility
toggle; onSuffixTap is ignored in that case.
Implementation
final IconData? suffixIcon;
Optional icon shown at the trailing edge of the field.
When obscureText is true this icon is replaced by a visibility
toggle; onSuffixTap is ignored in that case.
final IconData? suffixIcon;